############### Script for paper associations EMA study

#loading libraries and settings
library(haven)
library(ggplot2)
library(remotes)
library(esmpack)
library(gdata)
library(nlme)
library(correlation)
library(car)
library(MASS)
library(faraway)
library(lme4)
library(ggpubr)
library(tidyverse)
library(broom)
library(AICcmodavg)
library(lmerTest)
library(insight)
options(scipen=999)

#working directory and loading data - dataset without p032, p041 and p048
#name dataset: EMA_data
EMA_data <- read_sav("Samenvoeging Time based vragenlijst (EMA)_zonder drop out + snackdagboek (1).sav")

#exploring data 
ggplot(data=EMA_data,aes(x=Snack_portiegrootte_omgescoord_totaal)) +
  geom_histogram(binwidth=1, position = position_nudge(x=0.5)) +
  scale_x_continuous(name="Portiegrootte totaal",breaks=c(0,5,10,15,20,25,30)) +
  theme_minimal()

#summary of outcome variables
summary(EMA_data$Snack_gegeten)
summary(EMA_data$Healthfactor)
summary(EMA_data$Snack_portiegrootte_omgescoord_totaal)

#checking data (frequency tables)
nrow(EMA_data)
nsub(EMA_data$ID_proefpersoon)

#creating mean values at the subject-level for between-subject analysis
EMA_data$Snack_zichtbaarheid[EMA_data$Snack_beschikbaarheid== 3] <- 0
EMA_data$Snack_zichtbaarheid[EMA_data$Snack_beschikbaarheid== 2] <- 1

mean_intentie <- aggregate(EMA_data$Intentie, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_eenzaamheid <- aggregate(EMA_data$Emotie_eenzaamheid, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_vrolijk <- aggregate(EMA_data$Emotie_vrolijk, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_ontspannen <- aggregate(EMA_data$Emotie_ontspannen, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_enthousiast <- aggregate(EMA_data$Emotie_enthousiast, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_tevreden <- aggregate(EMA_data$Emotie_tevreden, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_onzeker <- aggregate(EMA_data$Emotie_onzeker, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_angstig <- aggregate(EMA_data$Emotie_angstig, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_geïrriteerd <- aggregate(EMA_data$Emotie_geïrriteerd, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_somber <- aggregate(EMA_data$Emotie_somber, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)

mean_socialmodeling <- aggregate(EMA_data$Snack_zieneten, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)
mean_zichtbaarheid <- aggregate(EMA_data$Snack_zichtbaarheid, by=list(EMA_data$ID_proefpersoon), mean, na.rm=T)

names(mean_intentie) <- c("ID_proefpersoon","mean_intentie")
names(mean_eenzaamheid) <- c("ID_proefpersoon","mean_eenzaamheid")
names(mean_vrolijk) <- c("ID_proefpersoon","mean_vrolijk")
names(mean_ontspannen) <- c("ID_proefpersoon","mean_ontspannen")
names(mean_enthousiast) <- c("ID_proefpersoon","mean_enthousiast")
names(mean_tevreden) <- c("ID_proefpersoon","mean_tevreden")
names(mean_onzeker) <- c("ID_proefpersoon","mean_onzeker")
names(mean_angstig) <- c("ID_proefpersoon","mean_angstig")
names(mean_geïrriteerd) <- c("ID_proefpersoon","mean_geïrriteerd")
names(mean_somber) <- c("ID_proefpersoon","mean_somber")

names(mean_socialmodeling) <- c("ID_proefpersoon","mean_socialmodeling")
names(mean_zichtbaarheid) <- c("ID_proefpersoon","mean_zichtbaarheid")

EMA_data <- merge(EMA_data,mean_intentie, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_eenzaamheid, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_vrolijk, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_ontspannen, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_enthousiast, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_tevreden, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_onzeker, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_angstig, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_geïrriteerd, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_somber, by='ID_proefpersoon')

EMA_data <- merge(EMA_data,mean_socialmodeling, by='ID_proefpersoon')
EMA_data <- merge(EMA_data,mean_zichtbaarheid, by='ID_proefpersoon')

# creating center values for within-subject analysis
EMA_data$Intentie_center <- EMA_data$Intentie - EMA_data$mean_intentie
EMA_data$Emotie_eenzaamheid_center <- EMA_data$Emotie_eenzaamheid - EMA_data$mean_eenzaamheid
EMA_data$Emotie_vrolijk_center <- EMA_data$Emotie_vrolijk - EMA_data$mean_vrolijk
EMA_data$Emotie_ontspannen_center <- EMA_data$Emotie_ontspannen - EMA_data$mean_ontspannen
EMA_data$Emotie_enthousiast_center <- EMA_data$Emotie_enthousiast - EMA_data$mean_enthousiast
EMA_data$Emotie_tevreden_center <- EMA_data$Emotie_tevreden - EMA_data$mean_tevreden
EMA_data$Emotie_onzeker_center <- EMA_data$Emotie_onzeker - EMA_data$mean_onzeker
EMA_data$Emotie_angstig_center <- EMA_data$Emotie_angstig - EMA_data$mean_angstig
EMA_data$Emotie_geïrriteerd_center <- EMA_data$Emotie_geïrriteerd - EMA_data$mean_geïrriteerd
EMA_data$Emotie_somber_center <- EMA_data$Emotie_somber - EMA_data$mean_somber

EMA_data$Socialmodeling_center <- EMA_data$Snack_zieneten - EMA_data$mean_socialmodeling
EMA_data$Zichtbaarheid_center <- EMA_data$Snack_zichtbaarheid - EMA_data$mean_zichtbaarheid

##### Graphs #####
# visualizing the data through the day
gg_eenzaamheid <- ggplot(EMA_data, aes(x=Dag , y=Emotie_eenzaamheid, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_loneliness")
print(gg_eenzaamheid)

gg_intentie <- ggplot(EMA_data, aes(x=Dag , y=Intentie, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Intention")
print(gg_intentie)

gg_vrolijk <- ggplot(EMA_data, aes(x=Dag , y=Emotie_vrolijk, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_cheerfulness")
print(gg_vrolijk)

gg_ontspannen <- ggplot(EMA_data, aes(x=Dag , y=Emotie_ontspannen, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_relaxation")
print(gg_ontspannen)

gg_enthousiast <- ggplot(EMA_data, aes(x=Dag , y=Emotie_enthousiast, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_enthusiasm")
print(gg_enthousiast)

gg_tevreden <- ggplot(EMA_data, aes(x=Dag , y=Emotie_tevreden, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_satisfaction")
print(gg_tevreden)

gg_onzeker <- ggplot(EMA_data, aes(x=Dag , y=Emotie_onzeker, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_insecurity")
print(gg_onzeker)

gg_angstig <- ggplot(EMA_data, aes(x=Dag , y=Emotie_angstig, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_anxiousness")
print(gg_angstig)

gg_geïrriteerd <- ggplot(EMA_data, aes(x=Dag , y=Emotie_geïrriteerd, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_irritation")
print(gg_geïrriteerd)

gg_somber <- ggplot(EMA_data, aes(x=Dag , y=Emotie_somber, group=Proefpersoon))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(EMA_data$Proefpersoon) +
  theme_bw() +
  labs(y = "Emotion_feeling down")
print(gg_somber)

##### Between- and within-subject variance #####
# calculating between- and within-subject variance for the time-based determinants

#Intention/Intentie
fit_intentie <- lmer(Intentie~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_intentie)

var_intentie <- get_variance(fit_intentie)
var_intentie$var.random/(var_intentie$var.residual+var_intentie$var.random) #68,9% of the variance is explained by differences between subject and between days
var_intentie$var.intercept[1]/(var_intentie$var.residual+var_intentie$var.random) #2,6% of the variance is explained by differences within subjects and between days
var_intentie$var.intercept[2]/(var_intentie$var.residual+var_intentie$var.random) #66,3% of the variance is explained by differences between the subjects
var_intentie$var.residual/(var_intentie$var.residual+var_intentie$var.random) #31,1% of the variance is explained by differences within subjects and within days

#Loneliness/Eenzaamheid
fit_eenzaamheid <- lmer(Emotie_eenzaamheid~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_eenzaamheid)

var_eenzaamheid <- get_variance(fit_eenzaamheid)
var_eenzaamheid$var.random/(var_eenzaamheid$var.residual+var_eenzaamheid$var.random) #56,0% of the variance is explained by differences between subject and between days
var_eenzaamheid$var.intercept[1]/(var_eenzaamheid$var.residual+var_eenzaamheid$var.random) #3,4% of the variance is explained by differences within subjects and between days
var_eenzaamheid$var.intercept[2]/(var_eenzaamheid$var.residual+var_eenzaamheid$var.random) #52,6% of the variance is explained by differences between the subjects
var_eenzaamheid$var.residual/(var_eenzaamheid$var.residual+var_eenzaamheid$var.random) #44,0% of the variance is explained by differences within subjects and within days

#Cheerfulness/Vrolijk
fit_vrolijk <- lmer(Emotie_vrolijk~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_vrolijk)

var_vrolijk <- get_variance(fit_vrolijk)
var_vrolijk$var.random/(var_vrolijk$var.residual+var_vrolijk$var.random) #52,1% of the variance is explained by differences between subject and between days
var_vrolijk$var.intercept[1]/(var_vrolijk$var.residual+var_vrolijk$var.random) #14,6% of the variance is explained by differences within subjects and between days
var_vrolijk$var.intercept[2]/(var_vrolijk$var.residual+var_vrolijk$var.random) #37,5% of the variance is explained by differences between the subjects
var_vrolijk$var.residual/(var_vrolijk$var.residual+var_vrolijk$var.random) #47,9% of the variance is explained by differences within subjects and within days

#Relaxation/Ontspannen
fit_ontspannen <- lmer(Emotie_ontspannen~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_ontspannen)

var_ontspannen <- get_variance(fit_ontspannen)
var_ontspannen$var.random/(var_ontspannen$var.residual+var_ontspannen$var.random) #55,3% of the variance is explained by differences between subject and between days
var_ontspannen$var.intercept[1]/(var_ontspannen$var.residual+var_ontspannen$var.random) #6,5% of the variance is explained by differences within subjects and between days
var_ontspannen$var.intercept[2]/(var_ontspannen$var.residual+var_ontspannen$var.random) #48,8% of the variance is explained by differences between the subjects
var_ontspannen$var.residual/(var_ontspannen$var.residual+var_ontspannen$var.random) #44,7% of the variance is explained by differences within subjects and within days

#Enthusiasm/Enthousiast
fit_enthousiast <- lmer(Emotie_enthousiast~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_enthousiast)

var_enthousiast <- get_variance(fit_enthousiast)
var_enthousiast$var.random/(var_enthousiast$var.residual+var_enthousiast$var.random) #58,6% of the variance is explained by differences between subject and between days
var_enthousiast$var.intercept[1]/(var_enthousiast$var.residual+var_enthousiast$var.random) #10,1% of the variance is explained by differences within subjects and between days
var_enthousiast$var.intercept[2]/(var_enthousiast$var.residual+var_enthousiast$var.random) #48,6% of the variance is explained by differences between the subjects
var_enthousiast$var.residual/(var_enthousiast$var.residual+var_enthousiast$var.random) #41,4% of the variance is explained by differences within subjects and within days

#Satisfaction/Tevreden
fit_tevreden <- lmer(Emotie_tevreden~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_tevreden)

var_tevreden <- get_variance(fit_tevreden)
var_tevreden$var.random/(var_tevreden$var.residual+var_tevreden$var.random) #49,1% of the variance is explained by differences between subject and between days
var_tevreden$var.intercept[1]/(var_tevreden$var.residual+var_tevreden$var.random) #1,5% of the variance is explained by differences within subjects and between days
var_tevreden$var.intercept[2]/(var_tevreden$var.residual+var_tevreden$var.random) #47,7% of the variance is explained by differences between the subjects
var_tevreden$var.residual/(var_tevreden$var.residual+var_tevreden$var.random) #50,9% of the variance is explained by differences within subjects and within days

#Insecurity/Onzeker
fit_onzeker <- lmer(Emotie_onzeker~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_onzeker)

var_onzeker <- get_variance(fit_onzeker)
var_onzeker$var.random/(var_onzeker$var.residual+var_onzeker$var.random) #50,6% of the variance is explained by differences between subject and between days
var_onzeker$var.intercept[1]/(var_onzeker$var.residual+var_onzeker$var.random) #4,8% of the variance is explained by differences within subjects and between days
var_onzeker$var.intercept[2]/(var_onzeker$var.residual+var_onzeker$var.random) #45,8% of the variance is explained by differences between the subjects
var_onzeker$var.residual/(var_onzeker$var.residual+var_onzeker$var.random) #49,4% of the variance is explained by differences within subjects and within days

#Anxiousness/Angstig
fit_angstig <- lmer(Emotie_angstig~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_angstig)

var_angstig <- get_variance(fit_angstig)
var_angstig$var.random/(var_angstig$var.residual+var_angstig$var.random) #52,0% of the variance is explained by differences between subject and between days
var_angstig$var.intercept[1]/(var_angstig$var.residual+var_angstig$var.random) #2,7% of the variance is explained by differences within subjects and between days
var_angstig$var.intercept[2]/(var_angstig$var.residual+var_angstig$var.random) #49,3% of the variance is explained by differences between the subjects
var_angstig$var.residual/(var_angstig$var.residual+var_angstig$var.random) #48,0% of the variance is explained by differences within subjects and within days

#Irritation/Geïrriteerd
fit_geïrriteerd <- lmer(Emotie_geïrriteerd~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_geïrriteerd)

var_geïrriteerd <- get_variance(fit_geïrriteerd)
var_geïrriteerd$var.random/(var_geïrriteerd$var.residual+var_geïrriteerd$var.random) #35,6% of the variance is explained by differences between subject and between days
var_geïrriteerd$var.intercept[1]/(var_geïrriteerd$var.residual+var_geïrriteerd$var.random) #5,2% of the variance is explained by differences within subjects and between days
var_geïrriteerd$var.intercept[2]/(var_geïrriteerd$var.residual+var_geïrriteerd$var.random) #30,4% of the variance is explained by differences between the subjects
var_geïrriteerd$var.residual/(var_geïrriteerd$var.residual+var_geïrriteerd$var.random) #64,4% of the variance is explained by differences within subjects and within days

#Feeling down/Somber
fit_somber <- lmer(Emotie_somber~ 1 +(1|ID_proefpersoon/Dag),data=EMA_data)
summary(fit_somber)

var_somber <- get_variance(fit_somber)
var_somber$var.random/(var_somber$var.residual+var_somber$var.random) #59,7% of the variance is explained by differences between subject and between days
var_somber$var.intercept[1]/(var_somber$var.residual+var_somber$var.random) #3,5% of the variance is explained by differences within subjects and between days
var_somber$var.intercept[2]/(var_somber$var.residual+var_somber$var.random) #56,2% of the variance is explained by differences between the subjects
var_somber$var.residual/(var_somber$var.residual+var_somber$var.random) #40,3% of the variance is explained by differences within subjects and within days

################################################################################################################
##### Decision to snack #####
#Type of models: logistic regression

##### Decision to snack - intention/intentie #####
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_intentie <- glmer(Snack_gegeten ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_intentie) #AIC = 1348.9
    
#Random intercept
  Snack_gegeten_binom_ri_intentie <- glmer(Snack_gegeten ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_intentie) #AIC = 1352.7
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_rr_intentie)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)

#### Decision to snack - lonelinsess/eenzaamheid ##### 
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_eenzaamheid <- glmer(Snack_gegeten ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_eenzaamheid) #AIC = 1360.8
    
#Random intercept
  Snack_gegeten_binom_ri_eenzaamheid <- glmer(Snack_gegeten ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_eenzaamheid) #AIC = 1358.1

#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_eenzaamheid)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)    
    
#### Decision to snack - cheerfulness/vrolijk #####
#Random slopes & random intercepts 
  Snack_gegeten_binom_rr_vrolijk <- glmer(Snack_gegeten ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_vrolijk) #AIC = 1359.0
    
#Random intercept
  Snack_gegeten_binom_ri_vrolijk <- glmer(Snack_gegeten ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_vrolijk) #AIC = 1357.8
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_vrolijk)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
    
#### Decision to snack - relaxation/ontspannen ##### 
#Random slopes & random intercepts 
  Snack_gegeten_binom_rr_ontspannen <- glmer(Snack_gegeten ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_ontspannen) #AIC = 1361.7
    
#Random intercept
  Snack_gegeten_binom_ri_ontspannen <- glmer(Snack_gegeten ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_ontspannen) #AIC = 1357.7
  
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_ontspannen)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci) 
    
#### Decision to snack - enthusiasm/enthousiast ##### 
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_enthousiast <- glmer(Snack_gegeten ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_enthousiast) #AIC = 1358.9
    
#Random intercept
  Snack_gegeten_binom_ri_enthousiast <- glmer(Snack_gegeten ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_enthousiast) #AIC = 1355.0

#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_enthousiast)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)    
    
#### Decision to snack - satisfaction/tevreden #####
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_tevreden <- glmer(Snack_gegeten ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_tevreden) #AIC = 1357.8
    
#Random intercept
  Snack_gegeten_binom_ri_tevreden <- glmer(Snack_gegeten ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_tevreden) #AIC = 1355.0
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_tevreden)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
    
#### Decision to snack - insecurity/onzeker #####
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_onzeker <- glmer(Snack_gegeten ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_onzeker) #AIC = 1358.9
    
#Random intercept
  Snack_gegeten_binom_ri_onzeker <- glmer(Snack_gegeten ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_onzeker) #AIC = 1354.9
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_onzeker)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
    
#### Decision to snack - anxiousness/angstig #####
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_angstig <- glmer(Snack_gegeten ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_angstig) #AIC = 1357.9
    
#Random intercept
  Snack_gegeten_binom_ri_angstig <- glmer(Snack_gegeten ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_angstig) #AIC = 1354.3
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_angstig)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
    
#### Decision to snack - irritation/geïrriteerd #####
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_geïrriteerd <- glmer(Snack_gegeten ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_geïrriteerd) #AIC = 1356.3
    
#Random intercept
  Snack_gegeten_binom_ri_geïrriteerd <- glmer(Snack_gegeten ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_geïrriteerd) #AIC = 1352.9
 
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_geïrriteerd)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)    

#### Decision to snack - feeling down/somber ##### 
#Random slopes & random intercepts
  Snack_gegeten_binom_rr_somber <- glmer(Snack_gegeten ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_rr_somber) #AIC = 1354.8
    
#Random intercept
  Snack_gegeten_binom_ri_somber <- glmer(Snack_gegeten ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), data=EMA_data, family= binomial(link="logit"))
  summary(Snack_gegeten_binom_ri_somber) #AIC = 1353.0
    
#Interpretation
  sum.coef<-summary(Snack_gegeten_binom_ri_somber)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
    
##### Health factor #####
#Type of models: Gaussian with identity, Gamma with identity and Gamma with log
  
##### Healthfactor - intention/intentie #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_intentie <- lmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_intentie)
    
  Healthfactor_gamma_id_rr_intentie <- glmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_intentie)
    
  Healthfactor_gamma_log_rr_intentie <- glmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_intentie)
    
#Random intercept
  Healthfactor_gauss_ri_intentie <- lmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_intentie)
    
  Healthfactor_gamma_id_ri_intentie <- glmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_intentie)
    
  Healthfactor_gamma_log_ri_intentie <- glmer(Snack_type_score_omgescoord ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_intentie)
    
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_intentie)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_intentie), LL = fixef(Healthfactor_gamma_id_ri_intentie) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_intentie) + 1.96 * se))
   
##### Healthfactor - visibility/zichtbaarheid #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_zichtbaarheid <- lmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_zichtbaarheid)
    
  Healthfactor_gamma_id_rr_zichtbaarheid <- glmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_zichtbaarheid)
    
  Healthfactor_gamma_log_rr_zichtbaarheid <- glmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_zichtbaarheid)
    
#Random intercept
  Healthfactor_gauss_ri_zichtbaarheid <- lmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_zichtbaarheid)
    
  Healthfactor_gamma_id_ri_zichtbaarheid <- glmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_zichtbaarheid)
  
  Healthfactor_gamma_log_ri_zichtbaarheid <- glmer(Snack_type_score_omgescoord ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_zichtbaarheid)
   
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_zichtbaarheid)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_zichtbaarheid), LL = fixef(Healthfactor_gamma_id_ri_zichtbaarheid) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_zichtbaarheid) + 1.96 * se))
    
##### Healthfactor - social modeling #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_socialmodeling <- lmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_socialmodeling)
    
  Healthfactor_gamma_id_rr_socialmodeling <- glmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_socialmodeling)
    
  Healthfactor_gamma_log_rr_socialmodeling <- glmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_socialmodeling)
    
#Random intercept
  Healthfactor_gauss_ri_socialmodeling <- lmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_socialmodeling)
    
  Healthfactor_gamma_id_ri_socialmodeling <- glmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_socialmodeling)
    
  Healthfactor_gamma_log_ri_socialmodeling <- glmer(Snack_type_score_omgescoord ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_socialmodeling)
   
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_socialmodeling)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_socialmodeling), LL = fixef(Healthfactor_gamma_id_ri_socialmodeling) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_socialmodeling) + 1.96 * se))
    
##### Healthfactor - loneliness/eenzaamheid #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_eenzaamheid <- lmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_eenzaamheid)
    
  Healthfactor_gamma_id_rr_eenzaamheid <- glmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_eenzaamheid)
    
  Healthfactor_gamma_log_rr_eenzaamheid <- glmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_eenzaamheid)
    
#Random intercept
  Healthfactor_gauss_ri_eenzaamheid <- lmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_eenzaamheid)
    
  Healthfactor_gamma_id_ri_eenzaamheid <- glmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_eenzaamheid)
    
  Healthfactor_gamma_log_ri_eenzaamheid <- glmer(Snack_type_score_omgescoord ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_eenzaamheid)
  
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_eenzaamheid)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_eenzaamheid), LL = fixef(Healthfactor_gamma_id_ri_eenzaamheid) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_eenzaamheid) + 1.96 * se))
    
##### Healthfactor - cheerfulness/vrolijk #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_vrolijk <- lmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_vrolijk)
    
  Healthfactor_gamma_id_rr_vrolijk <- glmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_vrolijk)
    
  Healthfactor_gamma_log_rr_vrolijk <- glmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_vrolijk)
    
#Random intercept
  Healthfactor_gauss_ri_vrolijk <- lmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_vrolijk)
    
  Healthfactor_gamma_id_ri_vrolijk <- glmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_vrolijk)
    
  Healthfactor_gamma_log_ri_vrolijk <- glmer(Snack_type_score_omgescoord ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_vrolijk)
  
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_vrolijk)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_vrolijk), LL = fixef(Healthfactor_gamma_id_ri_vrolijk) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_vrolijk) + 1.96 * se))
 
##### Healthfactor - relaxation/ontspannen #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_ontspannen <- lmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_ontspannen)
    
  Healthfactor_gamma_id_rr_ontspannen <- glmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_ontspannen)
    
  Healthfactor_gamma_log_rr_ontspannen <- glmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_ontspannen)
    
#Random intercept
  Healthfactor_gauss_ri_ontspannen <- lmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_ontspannen)
    
  Healthfactor_gamma_id_ri_ontspannen <- glmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_ontspannen)
    
  Healthfactor_gamma_log_ri_ontspannen <- glmer(Snack_type_score_omgescoord ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_ontspannen)

#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_ontspannen)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_ontspannen), LL = fixef(Healthfactor_gamma_id_ri_ontspannen) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_ontspannen) + 1.96 * se))
    
##### Healthfactor - enthusiasm/enthousiast #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_enthousiast <- lmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_enthousiast)
    
  Healthfactor_gamma_id_rr_enthousiast <- glmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_enthousiast)
    
  Healthfactor_gamma_log_rr_enthousiast <- glmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_enthousiast)
    
#Random intercept
  Healthfactor_gauss_ri_enthousiast <- lmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_enthousiast)
    
  Healthfactor_gamma_id_ri_enthousiast <- glmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_enthousiast)
    
  Healthfactor_gamma_log_ri_enthousiast <- glmer(Snack_type_score_omgescoord ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_enthousiast)
   
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_enthousiast)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_enthousiast), LL = fixef(Healthfactor_gamma_id_ri_enthousiast) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_enthousiast) + 1.96 * se))
    
##### Healthfactor - satisfaction/tevreden #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_tevreden <- lmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_tevreden)
    
  Healthfactor_gamma_id_rr_tevreden <- glmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_tevreden)
    
  Healthfactor_gamma_log_rr_tevreden <- glmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_tevreden)
    
#Random intercept
  Healthfactor_gauss_ri_tevreden <- lmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_tevreden)
    
  Healthfactor_gamma_id_ri_tevreden <- glmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_tevreden)
    
  Healthfactor_gamma_log_ri_tevreden <- glmer(Snack_type_score_omgescoord ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_tevreden)

#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_tevreden)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_tevreden), LL = fixef(Healthfactor_gamma_id_ri_tevreden) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_tevreden) + 1.96 * se))
    
##### Healthfactor - insecurity/onzeker #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_onzeker <- lmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_onzeker)
    
  Healthfactor_gamma_id_rr_onzeker <- glmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_onzeker)
    
  Healthfactor_gamma_log_rr_onzeker <- glmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_onzeker)
    
#Random intercept
  Healthfactor_gauss_ri_onzeker <- lmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_onzeker)
    
  Healthfactor_gamma_id_ri_onzeker <- glmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_onzeker)
    
  Healthfactor_gamma_log_ri_onzeker <- glmer(Snack_type_score_omgescoord ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_onzeker)
   
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_onzeker)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_onzeker), LL = fixef(Healthfactor_gamma_id_ri_onzeker) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_onzeker) + 1.96 * se))
    
##### Healthfactor - anxiousness/angstig #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_angstig <- lmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_angstig)
    
  Healthfactor_gamma_id_rr_angstig <- glmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_angstig)
    
  Healthfactor_gamma_log_rr_angstig <- glmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_angstig)
    
#Random intercept
  Healthfactor_gauss_ri_angstig <- lmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_angstig)
    
  Healthfactor_gamma_id_ri_angstig <- glmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_angstig)
    
  Healthfactor_gamma_log_ri_angstig <- glmer(Snack_type_score_omgescoord ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_angstig)
   
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_angstig)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_angstig), LL = fixef(Healthfactor_gamma_id_ri_angstig) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_angstig) + 1.96 * se))
    
##### Healthfactor - irritation/geïrriteerd #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_geïrriteerd <- lmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_geïrriteerd)
    
  Healthfactor_gamma_id_rr_geïrriteerd <- glmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_geïrriteerd)
    
  Healthfactor_gamma_log_rr_geïrriteerd <- glmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_geïrriteerd)
    
#Random intercept
  Healthfactor_gauss_ri_geïrriteerd <- lmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_geïrriteerd)
    
  Healthfactor_gamma_id_ri_geïrriteerd <- glmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_geïrriteerd)
    
  Healthfactor_gamma_log_ri_geïrriteerd <- glmer(Snack_type_score_omgescoord ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_geïrriteerd)
  
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_geïrriteerd)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_geïrriteerd), LL = fixef(Healthfactor_gamma_id_ri_geïrriteerd) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_geïrriteerd) + 1.96 * se))
    
##### Healthfactor - feeling down/somber #####
#Random slopes & random intercepts
  Healthfactor_gauss_rr_somber <- lmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_rr_somber)
    
  Healthfactor_gamma_id_rr_somber <- glmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_rr_somber)
    
  Healthfactor_gamma_log_rr_somber <- glmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_rr_somber)
    
#Random intercept
  Healthfactor_gauss_ri_somber <- lmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Healthfactor_gauss_ri_somber)
    
  Healthfactor_gamma_id_ri_somber <- glmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Healthfactor_gamma_id_ri_somber)
    
  Healthfactor_gamma_log_ri_somber <- glmer(Snack_type_score_omgescoord ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Healthfactor_gamma_log_ri_somber)
    
#Interpretation
  se <- sqrt(diag(vcov(Healthfactor_gamma_id_ri_somber)))
  (tab <- cbind(Est = fixef(Healthfactor_gamma_id_ri_somber), LL = fixef(Healthfactor_gamma_id_ri_somber) - 1.96 * se, UL = fixef(Healthfactor_gamma_id_ri_somber) + 1.96 * se))
    
##### Portion size #####
#Type of models: Gaussian with identity, Gamma with identity and Gamma with log
  
##### Portion size - intention/intentie #####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_intentie <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_intentie)
      
  Portiegrootte_gamma_id_rr_intentie <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_intentie)
      
  Portiegrootte_gamma_log_rr_intentie <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1+Intentie_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_intentie)
      
#Random intercept
  Portiegrootte_gauss_ri_intentie <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_intentie)
      
  Portiegrootte_gamma_id_ri_intentie <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_intentie)
    
  Portiegrootte_gamma_log_ri_intentie <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Intentie_center + mean_intentie + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_intentie)
      
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_intentie)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci) 

##### Portion size - visibility/zichtbaarheid #####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_zichtbaarheid <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_zichtbaarheid)
  
  Portiegrootte_gamma_id_rr_zichtbaarheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_zichtbaarheid)
  
  Portiegrootte_gamma_log_rr_zichtbaarheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1+Zichtbaarheid_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_zichtbaarheid)
  
#Random intercept
  Portiegrootte_gauss_ri_zichtbaarheid <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_zichtbaarheid)
  
  Portiegrootte_gamma_id_ri_zichtbaarheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_zichtbaarheid)
  
  Portiegrootte_gamma_log_ri_zichtbaarheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Zichtbaarheid_center + mean_zichtbaarheid + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_zichtbaarheid)
    
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_zichtbaarheid)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)    
        
##### Portion size - social modeling #####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_socialmodeling <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_socialmodeling)
    
  Portiegrootte_gamma_id_rr_socialmodeling <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_socialmodeling)
    
  Portiegrootte_gamma_log_rr_socialmodeling <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1+Socialmodeling_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_socialmodeling)
    
#Random intercept
  Portiegrootte_gauss_ri_socialmodeling <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_socialmodeling)
    
  Portiegrootte_gamma_id_ri_socialmodeling <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_socialmodeling)
    
  Portiegrootte_gamma_log_ri_socialmodeling <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Socialmodeling_center + mean_socialmodeling + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_socialmodeling)

#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_socialmodeling)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)  
    
#### Portion size - loneliness/eenzaamheid ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_eenzaamheid <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_eenzaamheid)
  
  Portiegrootte_gamma_id_rr_eenzaamheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_eenzaamheid)
  
  Portiegrootte_gamma_log_rr_eenzaamheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1+Emotie_eenzaamheid_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_eenzaamheid)
  
#Random intercept
  Portiegrootte_gauss_ri_eenzaamheid <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_eenzaamheid)
  
  Portiegrootte_gamma_id_ri_eenzaamheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_eenzaamheid)
  
  Portiegrootte_gamma_log_ri_eenzaamheid <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_eenzaamheid_center + mean_eenzaamheid + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_eenzaamheid)
    
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_eenzaamheid)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)

#### Portion size - cheerfulness/vrolijk ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_vrolijk <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_vrolijk)
  
  Portiegrootte_gamma_id_rr_vrolijk <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_vrolijk)
  
  Portiegrootte_gamma_log_rr_vrolijk <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1+Emotie_vrolijk_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_vrolijk)
  
#Random intercept
  Portiegrootte_gauss_ri_vrolijk <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_vrolijk)
  
  Portiegrootte_gamma_id_ri_vrolijk <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_vrolijk) 
  
  Portiegrootte_gamma_log_ri_vrolijk <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_vrolijk_center + mean_vrolijk + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_vrolijk)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_vrolijk)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
  
#### Portion size - relaxation/ontspannen ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_ontspannen <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_ontspannen)
  
  Portiegrootte_gamma_id_rr_ontspannen <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_ontspannen)
  
  Portiegrootte_gamma_log_rr_ontspannen <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1+Emotie_ontspannen_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_ontspannen)
  
#Random intercept
  Portiegrootte_gauss_ri_ontspannen <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_ontspannen)
  
  Portiegrootte_gamma_id_ri_ontspannen <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_ontspannen) 
  
  Portiegrootte_gamma_log_ri_ontspannen <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_ontspannen_center + mean_ontspannen + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_ontspannen)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_ontspannen)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)  
  
#### Portion size - enthusiasm/enthousiast ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_enthousiast <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_enthousiast)
  
  Portiegrootte_gamma_id_rr_enthousiast <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_enthousiast)
  
  Portiegrootte_gamma_log_rr_enthousiast <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1+Emotie_enthousiast_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_enthousiast)
  
#Random intercept
  Portiegrootte_gauss_ri_enthousiast <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_enthousiast)
  
  Portiegrootte_gamma_id_ri_enthousiast <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_enthousiast) 
  
  Portiegrootte_gamma_log_ri_enthousiast <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_enthousiast_center + mean_enthousiast + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_enthousiast)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_enthousiast)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
  
#### Portion size - satisfaction/tevreden ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_tevreden <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_tevreden)
  
  Portiegrootte_gamma_id_rr_tevreden <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_tevreden)
  
  Portiegrootte_gamma_log_rr_tevreden <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1+Emotie_tevreden_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_tevreden)
  
#Random intercept
  Portiegrootte_gauss_ri_tevreden <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_tevreden)
  
  Portiegrootte_gamma_id_ri_tevreden <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_tevreden)
  
  Portiegrootte_gamma_log_ri_tevreden <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_tevreden_center + mean_tevreden + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_tevreden)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_tevreden)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
  
#### Portion size - insecurity/onzeker ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_onzeker <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_onzeker)
  
  Portiegrootte_gamma_id_rr_onzeker <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_onzeker)
  
  Portiegrootte_gamma_log_rr_onzeker <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1+Emotie_onzeker_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_onzeker)
  
#Random intercept
  Portiegrootte_gauss_ri_onzeker <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_onzeker)
  
  Portiegrootte_gamma_id_ri_onzeker <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_onzeker)
 
  Portiegrootte_gamma_log_ri_onzeker <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_onzeker_center + mean_onzeker + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_onzeker)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_onzeker)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci) 
  
#### Portion size - anxiousness/angstig ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_angstig <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_angstig)
  
  Portiegrootte_gamma_id_rr_angstig <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_angstig)
  
  Portiegrootte_gamma_log_rr_angstig <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1+Emotie_angstig_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_angstig)
  
#Random intercept
  Portiegrootte_gauss_ri_angstig <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_angstig)
  
  Portiegrootte_gamma_id_ri_angstig <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_angstig)

  Portiegrootte_gamma_log_ri_angstig <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_angstig_center + mean_angstig + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_angstig)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_angstig)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)
  
#### Portion size - irritation/geïrriteerd ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_geïrriteerd <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_geïrriteerd)
  
  Portiegrootte_gamma_id_rr_geïrriteerd <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_geïrriteerd)
  
  Portiegrootte_gamma_log_rr_geïrriteerd <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1+Emotie_geïrriteerd_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_geïrriteerd)
  
#Random intercept
  Portiegrootte_gauss_ri_geïrriteerd <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_geïrriteerd)
  
  Portiegrootte_gamma_id_ri_geïrriteerd <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_geïrriteerd)
  
  Portiegrootte_gamma_log_ri_geïrriteerd <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_geïrriteerd_center + mean_geïrriteerd + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_geïrriteerd)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_geïrriteerd)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci)  
  
#### Portion size - feeling down/somber ####
#Random slopes & random intercepts
  Portiegrootte_gauss_rr_somber <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_rr_somber)
  
  Portiegrootte_gamma_id_rr_somber <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_rr_somber)
  
  Portiegrootte_gamma_log_rr_somber <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1+Emotie_somber_center|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_rr_somber)
  
#Random intercept
  Portiegrootte_gauss_ri_somber <- lmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), REML=F, data=EMA_data)
  summary(Portiegrootte_gauss_ri_somber)
  
  Portiegrootte_gamma_id_ri_somber <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), family=Gamma(link="identity"), data=EMA_data)
  summary(Portiegrootte_gamma_id_ri_somber)
  
  Portiegrootte_gamma_log_ri_somber <- glmer(Snack_portiegrootte_omgescoord_totaal ~ Emotie_somber_center + mean_somber + (1|ID_proefpersoon), family=Gamma(link="log"), data=EMA_data)
  summary(Portiegrootte_gamma_log_ri_somber)
  
#Interpretation
  sum.coef<-summary(Portiegrootte_gamma_log_ri_somber)$coef
  sum.coef
  est<-exp(sum.coef[,1])
  upper.ci<-exp(sum.coef[,1]+1.96*sum.coef[,2])
  lower.ci<-exp(sum.coef[,1]-1.96*sum.coef[,2])
  cbind(est,lower.ci,upper.ci) 
  